@@ -144,6 +144,15 @@ class MagicHandler(ABC):
         """
         Return True if the source contains ipython magic.
 
+        A statement like ``%%timeit get_ipython().run_line_magic("magic", "input")``
+        already contains ``get_ipython()`` function call. To handle such cases, we need
+        to check if the original source itself contains any ``get_ipython()`` function
+        call before concluding the statement is an ipython magic.
+
+        A statement like ``some_result = str.split??`` gets transformed into two
+        python statements when using ``IPythonInputSplitter.transform_cell``. Thus we
+        need to check if the count is more than the count on the input source.
+
         Parameters
         ----------
         source : str
@@ -154,17 +163,8 @@ class MagicHandler(ABC):
         bool
             True if the source contains ipython magic
         """
-        # suppose a developer is developing a custom cell magic or line magic
-        # and wants to measure the performance of it using a code snippet like
-        # `%%timeit get_ipython().run_line_magic("custom_magic", "input to magic")`
-        # To handle such cases, we need to count if the original source itself
-        # contains any `get_ipython` function call.
-        # If the statement is a valid ipython magic, then ipython2python
-        # will transform using another `get_ipython()` function call.
         src_count = source.count("get_ipython()")
-        return INPUT_SPLITTER.transform_cell(source).count("get_ipython()") == (
-            1 + src_count
-        )
+        return INPUT_SPLITTER.transform_cell(source).count("get_ipython()") > src_count
 
     @staticmethod
     def get_ipython_magic_type(ipython_magic: str) -> Optional[IPythonMagicType]:
@@ -192,6 +192,33 @@ class MagicHandler(ABC):
 
         return magic_type
 
+    @staticmethod
+    def preprocess_ipython_magic(ipython_magic: str) -> str:
+        r"""
+        Remove leading and trailing spaces, trailing slashes from ipython magic.
+
+        If the trailing slashes are present in ipython magic(its an incomplete magic),
+        then we would have issues with ``re.sub`` when replacing the ipython magic back
+        to the cell source. ``re.compile("something ending with slash\\")`` will fail to
+        compile. By stripping trailing slashes, the regex would compile fine during
+        substitution.
+
+        Parameters
+        ----------
+        ipython_magic : str
+            IPython magic
+
+        Returns
+        -------
+        str
+            IPython magic stripped of spaces and trailing slashes
+        """
+        ipython_magic = dedent(ipython_magic).strip()
+        if INPUT_SPLITTER.check_complete(ipython_magic)[0] == "incomplete":
+            ipython_magic = ipython_magic.rstrip("\\")
+
+        return ipython_magic
+
     @staticmethod
     def get_magic_handler(ipython_magic: str) -> "MagicHandler":
         """
@@ -202,7 +229,7 @@ class MagicHandler(ABC):
         MagicHandler
             An instance of MagicHandler or some subclass of MagicHandler.
         """
-        ipython_magic = dedent(ipython_magic).strip()
+        ipython_magic = MagicHandler.preprocess_ipython_magic(ipython_magic)
         magic_type = MagicHandler.get_ipython_magic_type(ipython_magic)
 
         magic_handler: MagicHandler
